# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.profile_api import ProfileApi  # noqa: E501


class TestProfileApi(unittest.TestCase):
    """ProfileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProfileApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_create_api_key(self) -> None:
        """Test case for create_api_key

        """
        pass

    def test_delete_api_key(self) -> None:
        """Test case for delete_api_key

        """
        pass

    def test_get_api_keys(self) -> None:
        """Test case for get_api_keys

        """
        pass

    def test_get_preferences(self) -> None:
        """Test case for get_preferences

        """
        pass

    def test_get_profile(self) -> None:
        """Test case for get_profile

        """
        pass

    def test_get_profile_details(self) -> None:
        """Test case for get_profile_details

        """
        pass

    def test_get_zendesk_chat_token(self) -> None:
        """Test case for get_zendesk_chat_token

        """
        pass

    def test_update_preferences(self) -> None:
        """Test case for update_preferences

        """
        pass

    def test_update_profile_details(self) -> None:
        """Test case for update_profile_details

        """
        pass


if __name__ == '__main__':
    unittest.main()
