# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 5.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_values import ParticipantDashboardInterconnectorCapacityDataMtusValues  # noqa: E501

class TestParticipantDashboardInterconnectorCapacityDataMtusValues(unittest.TestCase):
    """ParticipantDashboardInterconnectorCapacityDataMtusValues unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardInterconnectorCapacityDataMtusValues:
        """Test ParticipantDashboardInterconnectorCapacityDataMtusValues
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardInterconnectorCapacityDataMtusValues`
        """
        model = ParticipantDashboardInterconnectorCapacityDataMtusValues()  # noqa: E501
        if include_optional:
            return ParticipantDashboardInterconnectorCapacityDataMtusValues(
                direction = 'GB_NL',
                data = empire_platform_api_public_client.models.ntc_overview_mtu_data.NtcOverviewMtuData(
                    default_capacity = 56, 
                    effective_addition = 56, 
                    effective_reduction = 56, 
                    ntc = 56, )
            )
        else:
            return ParticipantDashboardInterconnectorCapacityDataMtusValues(
                direction = 'GB_NL',
                data = empire_platform_api_public_client.models.ntc_overview_mtu_data.NtcOverviewMtuData(
                    default_capacity = 56, 
                    effective_addition = 56, 
                    effective_reduction = 56, 
                    ntc = 56, ),
        )
        """

    def testParticipantDashboardInterconnectorCapacityDataMtusValues(self):
        """Test ParticipantDashboardInterconnectorCapacityDataMtusValues"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
